@@ -4,7 +4,7 @@ APP_TEMPLATE = f'''\
 from {{{keys.BASE}}}.components.index import Layout
 from {{{keys.BASE}}}.server import app
 
-# In order for callbacks to work, they must be imported where Dash is instantiated 
+# In order for callbacks to work, they must be imported where Dash is instantiated
 # noinspection PyUnresolvedReferences
 import {{{keys.BASE}}}.callbacks.index
 
@@ -14,10 +14,13 @@ app.layout = Layout
 
 if __name__ == '__main__':
     app.runserver(debug=True)
-    
+
 '''
 
 SERVER_TEMPLATE = f'''\
+import os
+
+from flask_cache import Cache
 import dash
 import dash_bootstrap_components as dbc
 
@@ -25,18 +28,18 @@ import dash_bootstrap_components as dbc
 app = dash.Dash(
     __name__,
     external_stylesheets=[
-        dbc.themes.CYBORG, 
+        dbc.themes.CYBORG,
     ],
     # Dash throws exceptions about callbacks from components that might be not loaded yet if
     # elements like Tabs are used. These alerts are annoying so suppress them.
     suppress_callback_exceptions=True,
-    title={{{keys.TITLE}}},
+    title='{{{keys.TITLE}}}',
 )
 cache = Cache(
     app.server,
     config={{{{
         'CACHE_TYPE': 'filesystem',
-        'CACHE_DIR': os.path.join({{{keys.CACHE_PATH}}}, 'dash-cache'),
+        'CACHE_DIR': os.path.join('{{{keys.CACHE_PATH}}}', 'dash-cache'),
     }}}}
 )
 
